@@ -1,8 +1,8 @@
 from com import Component, msgs
+from utils import logging
 import platforms
 
 
-
 class RotationMonitor(Component):
     """
     Monitor for detecting rotating the device.
@@ -22,18 +22,20 @@ class RotationMonitor(Component):
 
 
     def handle_ASR_ACT_ENABLE(self, value):
-    
+
         self.__is_automatic = value
 
-                                 
+
     def __on_rotate(self, orientation, stand_mode, face_mode,
                     axis1, axis2, axis3):
-    
+
+        logging.debug("[rotationmonitor] device rotated: %s, %s",
+                      orientation, face_mode)
         if (not self.__is_automatic): return
-    
+
         if (orientation in ("landscape", "landscape (inverted)")):
             self.emit_message(msgs.ASR_EV_LANDSCAPE)
-            
+
         elif (orientation == "portrait"):
             self.emit_message(msgs.ASR_EV_PORTRAIT)
 
