@@ -1,6 +1,7 @@
 from com import FileInspector, msgs
 
 import os
+import time
 
 
 class ImageInspector(FileInspector):
@@ -24,7 +25,12 @@ class ImageInspector(FileInspector):
         basename = os.path.basename(path)
         dirname = os.path.dirname(path)
         
+        ctime = os.path.getctime(path)
+        t = time.localtime(ctime)
+        
         entry["File.Type"] = "image"
         entry["Image.Title"] = os.path.splitext(basename)[0].replace("_", " ")
         entry["File.Folder"] = os.path.basename(dirname)
+        entry["Image.Month"] = t.tm_mon
+        entry["Image.Year"] = t.tm_year
 
