@@ -15,7 +15,8 @@ _BLACKLIST = ["media:///",
 
 class HistoryDevice(Device):
     """
-    Device for collecting and listing the runtime history of visited folders.
+    Storage device for collecting and listing the history of recently visited
+    folders.
     """
 
     CATEGORY = Device.CATEGORY_HIDDEN
@@ -38,19 +39,19 @@ class HistoryDevice(Device):
         
     def get_name(self):
     
-        return "History"
+        return "Recently Visited Folders"
         
 
     def get_icon(self):
     
-        return theme.mb_device_folders
+        return None
         
         
     def get_root(self):
     
         f = File(self)
         f.name = self.get_name()
-        f.info = "History of visited places"
+        f.info = "History of recently visited folders"
         f.path = "/"
         f.mimetype = f.DEVICE_ROOT
 
