@@ -2,7 +2,7 @@ from com import Component, Dialog, Widget, msgs
 from NowPlaying import NowPlaying
 from RootDevice import RootDevice
 from mediabox.StorageBrowser import StorageBrowser
-from ui.Button import Button
+from ui.ToolbarButton import ToolbarButton
 from ui.ImageButton import ImageButton
 from ui.Toolbar import Toolbar
 from ui.dialog import InputDialog
@@ -31,13 +31,13 @@ import os
 _LANDSCAPE_ARRANGEMENT = """
   <arrangement>
     <widget name="toolbar"
-            x1="-80" y1="0" x2="100%" y2="100%"/>
+            x1="-100" y1="0" x2="100%" y2="100%"/>
 
     <widget name="now-playing"
-            x1="-160" y1="0" x2="-80" y2="100%"/>
+            x1="-180" y1="0" x2="-100" y2="100%"/>
 
     <widget name="browser"
-            x1="0" y1="0" x2="-160" y2="100%"/>
+            x1="0" y1="0" x2="-180" y2="100%"/>
   </arrangement>
 """
 
@@ -45,13 +45,13 @@ _LANDSCAPE_ARRANGEMENT = """
 _PORTRAIT_ARRANGEMENT = """
   <arrangement>
     <widget name="toolbar"
-            x1="0" y1="-80" x2="100%" y2="100%"/>
+            x1="0" y1="-100" x2="100%" y2="100%"/>
 
     <widget name="now-playing"
             x1="0" y1="0" x2="100%" y2="80"/>
 
     <widget name="browser"
-            x1="0" y1="80" x2="100%" y2="-80"/>
+            x1="0" y1="80" x2="100%" y2="-100"/>
   </arrangement>
 """
 
@@ -128,36 +128,30 @@ class Navigator(Component, Window):
         self.__browser.connect_folder_progress(self.__on_progress_folder)
         self.__browser.connect_folder_complete(self.__on_complete_folder)
         self.__browser.connect_file_opened(self.__on_open_file)
+        self.__browser.connect_item_shifted(self.__on_shift_item)
 
         # toolbar
         self.__toolbar = Toolbar()
 
-        self.__btn_home = ImageButton(theme.mb_btn_home_1,
-                                      theme.mb_btn_home_2)
+        self.__btn_home = ToolbarButton(theme.mb_btn_home_1)
         self.__btn_home.connect_clicked(self.__on_btn_home)
         
-        self.__btn_history = ImageButton(theme.mb_btn_history_1,
-                                         theme.mb_btn_history_2)
+        self.__btn_history = ToolbarButton(theme.mb_btn_history_1)
         self.__btn_history.connect_clicked(self.__on_btn_history)
 
-        self.__btn_bookmarks = ImageButton(theme.mb_btn_bookmark_1,
-                                           theme.mb_btn_bookmark_2)
+        self.__btn_bookmarks = ToolbarButton(theme.mb_btn_bookmark_1)
         self.__btn_bookmarks.connect_clicked(self.__on_btn_bookmarks)
 
-        self.__btn_back = ImageButton(theme.mb_btn_dir_up_1,
-                                      theme.mb_btn_dir_up_2)
+        self.__btn_back = ToolbarButton(theme.mb_btn_dir_up_1)
         self.__btn_back.connect_clicked(self.__on_btn_back)
 
-        self.__btn_select_all = ImageButton(theme.mb_btn_select_all_1,
-                                            theme.mb_btn_select_all_2)
+        self.__btn_select_all = ToolbarButton(theme.mb_btn_select_all_1)
         self.__btn_select_all.connect_clicked(self.__on_btn_select_all)
 
-        self.__btn_select_none = ImageButton(theme.mb_btn_select_none_1,
-                                             theme.mb_btn_select_none_2)
+        self.__btn_select_none = ToolbarButton(theme.mb_btn_select_none_1)
         self.__btn_select_none.connect_clicked(self.__on_btn_select_none)
 
-        self.__btn_select_done = ImageButton(theme.mb_btn_select_done_1,
-                                             theme.mb_btn_select_done_2)
+        self.__btn_select_done = ToolbarButton(theme.mb_btn_select_done_1)
         self.__btn_select_done.connect_clicked(self.__on_btn_select_done)
 
 
@@ -253,12 +247,18 @@ class Navigator(Component, Window):
     def __update_items_per_row(self, folder):
 
         w, h = self.get_size()
-        
+        if (w > h):
+            w -= 180
+
         if (folder and folder.folder_flags & folder.ITEMS_COMPACT):
-            if (w < h):
-                self.__browser.set_items_per_row(3)
+            if (w > 0):
+                per_row = w / 160
             else:
-                self.__browser.set_items_per_row(4)
+                per_row = 3
+            #if (w < h):
+            self.__browser.set_items_per_row(per_row)
+            #else:
+            #    self.__browser.set_items_per_row(4)
         else:
             self.__browser.set_items_per_row(1)
             
@@ -378,7 +378,7 @@ class Navigator(Component, Window):
         
         if (dlg.run() == dlg.RETURN_OK):
             url = dlg.get_values()[0]
-            self.__load_url(url)
+            self.__load_uri(url, "")
         #end if
         
 
@@ -419,11 +419,10 @@ class Navigator(Component, Window):
 
 
     def __on_begin_folder(self, f):
-    
-        self.__tn_scheduler.new_schedule(5, self.__on_load_thumbnail)
+        
+        self.__tn_scheduler.new_schedule(25, self.__on_load_thumbnail)
         self.__tn_scheduler.halt()
         
-        #self.set_title(f.name)
         self.set_flag(windowflags.BUSY, True)
         
         self.__browser.set_filter()
@@ -431,9 +430,9 @@ class Navigator(Component, Window):
         
         self.__update_layout()
         self.__update_menu()
-        self.render()
         
         self.__update_items_per_row(f)
+        self.__browser.render()
 
         # set platform-specific click behavior
         if (platforms.MAEMO4):
@@ -445,23 +444,18 @@ class Navigator(Component, Window):
                 
 
     def __on_progress_folder(self, f, c):
-
-        if (f == self.__play_folder and not c.mimetype.endswith("-folder")):
-            if (not c in self.__play_files):
-                self.__play_files.append(c)
-            if (not c in self.__random_files):
-                self.__random_files.append(c)
-
+    
         if (not c.icon):
-            item = self.__browser.get_items()[-1]
+            items = self.__browser.get_items()
+            item = items[-1]
+            
             thumbpath, is_final = \
               self.call_service(msgs.THUMBNAIL_SVC_LOOKUP_THUMBNAIL, c)
 
             item.set_icon(thumbpath)
             
             if (not is_final):
-                #print "SCHEDULING THUMBNAIL", c
-                self.__tn_scheduler.add(item, c)
+                self.__tn_scheduler.add(item, c, False)
         #end if
 
 
@@ -481,11 +475,17 @@ class Navigator(Component, Window):
 
         if (self.is_visible()):
             self.__tn_scheduler.resume()
-            
+
+
+    def __on_shift_item(self, pos, amount):
+    
+        if (self.__browser.get_current_folder() == self.__play_folder):
+            # force invalidation of play files
+            self.__play_files = []
+
 
     def __update_thumbnail(self, item, thumbpath):
     
-        #pass
         item.set_icon(thumbpath)
         try:
             idx = self.__browser.get_items().index(item)
@@ -494,10 +494,12 @@ class Navigator(Component, Window):
             pass
 
 
-    def __on_load_thumbnail(self, item, f):
+    def __on_load_thumbnail(self, item, f, quick):
+        """
+        Scheduler callback handler for loading the next thumbnail.
+        """
 
         def on_loaded(thumbpath):
-            #print "LOADED THUMBNAIL", thumbpath
             if (thumbpath):
                 self.__update_thumbnail(item, thumbpath)
             
@@ -508,14 +510,22 @@ class Navigator(Component, Window):
                 if (top_idx < len(items)):
                     self.__tn_scheduler.priorize(items[top_idx:top_idx + 12])
             #end if
-            
-            self.__tn_scheduler.resume()
-            #print "RESUMING SCHEDULER"
+            gobject.idle_add(self.__tn_scheduler.resume)
     
         # load thumbnail
         self.__tn_scheduler.halt()
-        #print "HALTING SCHEDULER"
-        self.call_service(msgs.THUMBNAIL_SVC_LOAD_THUMBNAIL, f, on_loaded)
+        if (quick):
+            thumbpath, is_final = \
+              self.call_service(msgs.THUMBNAIL_SVC_LOOKUP_THUMBNAIL, f)
+            on_loaded(thumbpath)
+                        
+            if (not is_final):
+                #print "SCHEDULING THUMBNAIL", c
+                self.__tn_scheduler.add(item, f, False)
+            self.__tn_scheduler.resume()
+
+        else:
+            self.call_service(msgs.THUMBNAIL_SVC_LOAD_THUMBNAIL, f, on_loaded)
         
 
     def __on_btn_home(self):
@@ -605,6 +615,8 @@ class Navigator(Component, Window):
         #    applet_id = f.resource
         #    self.call_service(msgs.CORE_SVC_LAUNCH_APPLET, applet_id)
 
+        stopwatch = logging.stopwatch()
+        
         if (f.mimetype == f.CONFIGURATOR):
             cfg_name = f.resource
             self.emit_message(msgs.UI_ACT_SHOW_DIALOG, cfg_name)
@@ -623,17 +635,17 @@ class Navigator(Component, Window):
             folder = self.__browser.get_current_folder()
             if (is_manual and folder != self.__play_folder):
                 self.__play_folder = folder
-                self.__play_files = [ fl for fl in self.__browser.get_files()
-                                      if not fl.mimetype.endswith("-folder") ]
                 self.__random_files = []
-                logging.debug("[navigator] clearing random items")
-
+                self.__invalidate_play_files()
+        
+        logging.profile(stopwatch, "[navigator] loaded file")
 
 
     def __go_previous(self):
 
         now = time.time()
-        self.__filter_play_files()
+        if (not self.__play_files):
+            self.__invalidate_play_files()
         
         try:
             idx = self.__play_files.index(self.__current_file)
@@ -649,8 +661,9 @@ class Navigator(Component, Window):
             
     def __go_next(self):
 
-        now = time.time()
-        self.__filter_play_files()
+        stopwatch = logging.stopwatch()
+        if (not self.__play_files):
+            self.__invalidate_play_files()
         
         repeat_mode = mb_config.repeat_mode()
         shuffle_mode = mb_config.shuffle_mode()
@@ -681,7 +694,7 @@ class Navigator(Component, Window):
             elif (shuffle_mode == mb_config.SHUFFLE_MODE_ALL):
                 self.__play_shuffled(True)
             
-        logging.profile(now, "[navigator] loaded next item")
+        logging.profile(stopwatch, "[navigator] loaded next item")
         
 
     def __play_same(self):
@@ -711,7 +724,16 @@ class Navigator(Component, Window):
             
         else:
             return False
-
+            """
+            self.__play_folder = self.__browser.get_current_folder()
+            self.__invalidate_play_files()
+            if (self.__play_files):
+                next_item = self.__play_files[0]
+                self.__load_file(next_item, False)
+                return True
+            else:
+                return False
+            """
         
         
     def __play_shuffled(self, from_all):
@@ -722,8 +744,6 @@ class Navigator(Component, Window):
 
         if (not self.__random_files):
             self.__random_files = self.__play_files[:]
-            logging.debug("[navigator] initialising random items (%d items)",
-                          len(self.__random_files))
 
         idx = random.randint(0, len(self.__random_files) - 1)
         next_item = self.__random_files.pop(idx)
@@ -735,6 +755,35 @@ class Navigator(Component, Window):
         return True
 
 
+    def __invalidate_play_files(self):
+        """
+        Invalidates the play files and random files and rebuilds them.
+        """
+
+        profile_now = time.time()
+        
+        prev_play_files = self.__play_files
+        self.__play_files = [ f for f in self.__play_folder.get_children()
+                              if not f.mimetype.endswith("-folder") ]
+
+        size = len(self.__play_files)
+        img_size = len([f for f in self.__play_files
+                        if f.mimetype in mimetypes.get_image_types() ])
+        ratio = img_size / float(size)
+        
+        if (ratio < 0.5):
+            self.__play_files = [ f for f in self.__play_files
+                             if not f.mimetype in mimetypes.get_image_types() ]
+
+        new_files = [ f for f in self.__play_files if not f in prev_play_files ]
+
+        self.__random_files = [ f for f in self.__random_files
+                                if f in self.__play_files ] + new_files
+        
+        logging.profile(profile_now, "[navigator] invalidated list of files " \
+                                     "to play")
+
+
     def __filter_play_files(self):
         """
         Filters the list of playfiles to see if there's cover art to remove
@@ -789,11 +838,11 @@ class Navigator(Component, Window):
     def render_this(self):
     
         w, h = self.get_size()
-        
-        if ((w, h) != self.__window_size):
+
+        if ((w, h) != self.__window_size):            
             self.__update_items_per_row(self.__browser.get_current_folder())
-            self.__window_size = (w, h)
-    
+            self.__window_size = (w, h)    
+
         if (self.__arr.is_visible()):
             Window.render_this(self)
             
@@ -867,9 +916,9 @@ class Navigator(Component, Window):
             #end for
             self.__browser.set_path_stack(path_stack)
             
-            self.__play_files = [ self.call_service(msgs.CORE_SVC_GET_FILE, p)
-                                  for p in play_files
-                                  if self.call_service(msgs.CORE_SVC_GET_FILE, p) ]
+            #self.__play_files = [ self.call_service(msgs.CORE_SVC_GET_FILE, p)
+            #                      for p in play_files
+            #                      if self.call_service(msgs.CORE_SVC_GET_FILE, p) ]
             self.__play_folder = self.call_service(msgs.CORE_SVC_GET_FILE,
                                                    play_folder)
             self.__current_file = self.call_service(msgs.CORE_SVC_GET_FILE,
@@ -897,12 +946,16 @@ class Navigator(Component, Window):
     def handle_COM_EV_APP_SHUTDOWN(self):
 
         self.__is_shutdown = True
-        self.render()
+        #self.render()
         
-        while (gtk.events_pending()): gtk.main_iteration(True)
+        #while (gtk.events_pending()): gtk.main_iteration(True)
         self.__save_state()
 
 
+    def handle_CORE_EV_THEME_CHANGED(self):
+    
+        self.render()
+
 
     def handle_CORE_EV_DEVICE_ADDED(self, ident, device):
             
@@ -919,11 +972,6 @@ class Navigator(Component, Window):
     def handle_UI_ACT_SHOW_DIALOG(self, name):
     
         self.__show_dialog(name)
-
-
-    def handle_CORE_EV_THEME_CHANGED(self):
-    
-        self.render()
       
 
     def handle_CORE_EV_FOLDER_INVALIDATED(self, folder):
@@ -934,6 +982,9 @@ class Navigator(Component, Window):
             self.__browser.invalidate_folder(folder)
             
         if (folder and folder == self.__play_folder):
+            self.__invalidate_play_files()
+        
+            """
             prev_play_files = self.__play_files[:]
             self.__play_files = [ fl for fl in folder.get_children()
                                   if not fl.mimetype.endswith("-folder") ]
@@ -947,7 +998,7 @@ class Navigator(Component, Window):
                                        f not in prev_play_files ]
             logging.debug("[navigator] previously %d random items, now %d",
                           l, len(self.__random_files))
-           
+            """
 
 
     def handle_CORE_EV_DEVICE_REMOVED(self, dev_id):
