@@ -4,8 +4,12 @@ from utils.MiniXML import MiniXML
 from io import Downloader
 from upnp.DeviceDescription import DeviceDescription
 from utils import logging
+from utils import network
 
 import gobject
+import threading
+import socket
+import select
 
 
 _NS_DESCR = "urn:schemas-upnp-org:device-1-0"
@@ -27,32 +31,66 @@ class SSDPMonitor(Component):
         # table of the devices currently being processed: UUID -> location
         self.__processing = {}
 
-        self.__monitoring = False
-        self.__discovery_monitor = None
     
         Component.__init__(self)
             
-
-    def __discovery_chain(self, sock, i):
+            
+    def __start_discovery(self):
     
-        if (i == 0):
-            ssdp.discover_devices()
-            gobject.timeout_add(6000, self.__discovery_chain, sock, i + 1)
-        elif (i == 1):
-            ssdp.discover_devices()
-            gobject.timeout_add(6000, self.__discovery_chain, sock, i + 1)
-        elif (i == 2):
-            pass
-            #gobject.source_remove(self.__discovery_monitor)
-            #sock.close()
+        t = threading.Thread(target = self.__discovery_thread)
+        t.setDaemon(True)
+        t.start()
+            
 
+    def __discovery_thread(self):
+    
+        sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM,
+                             socket.IPPROTO_UDP)
+        sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+        
+        for i in range(3):
+            ssdp.broadcast_msearch(sock)
+            while (True):
+                r_socks, w_socks, x_socks = select.select([sock], [], [], 6)
+                if (r_socks):
+                    # process response
+                    r_sock = r_socks[0]
+                    data, addr = r_sock.recvfrom(1024)
+                    
+                    if (not "\r\n\r\n" in data):
+                        continue
+                    
+                    headers = network.HTTPHeaders(data)
+                    
+                    if (headers.http_type == headers.TYPE_INVALID or
+                          headers.status != 200):
+                        continue
+                    
+                    # ignore MediaBox from the same IP (i.e. myself)
+                    if (headers["X-MEDIABOX-IGNORE"] == network.get_ip()):
+                        continue
+                    
+                    uuid = headers["USN"]
+                    location = headers["LOCATION"]
+                    max_age = ssdp.parse_max_age(headers["CACHE-CONTROL"])
+                    
+                    gobject.timeout_add(0, self.__handle_ssdp_alive,
+                                        uuid, location, max_age)
+                    
+                else:
+                    # timeout
+                    break
+            #end while
+        #end for
+        logging.debug("[ssdp monitor] discovering finished")
+        
 
     def __on_expire(self, uuid):
         """
         Timer for removing UPnP devices that expire.
         """
         
-        logging.debug("UPnP device [%s] has expired", uuid)
+        logging.debug("[ssdp monitor] device expired: %s", uuid)
         del self.__expiration_handlers[uuid]
         self.__handle_ssdp_byebye(uuid)
             
@@ -80,39 +118,26 @@ class SSDPMonitor(Component):
                 descr = DeviceDescription(location, dom)
             
                 # announce availability of device
-                logging.info("discovered UPnP device [%s] of type [%s]" \
+                logging.info("[ssdp monitor] device discovered: %s (%s)" \
                              % (descr.get_friendly_name(), descr.get_device_type()))
-                logging.debug("propagating availability of device [%s]" % uuid)
+                logging.debug("[ssdp monitor] propagating device: %s" % uuid)
                 self.emit_message(msgs.SSDP_EV_DEVICE_DISCOVERED, uuid, descr)
             #end if
         #end if
-        
-
-    def __check_ssdp(self, sock, cond):
     
-        ssdp_event = ssdp.poll_event(sock)
-        if (ssdp_event):
-            event, location, usn, max_age = ssdp_event
-            if ("::" in usn):
-                uuid, urn = usn.split("::")
-            else:
-                uuid = usn
-                urn = ""
+    
+    def __parse_subscription(self, req):
 
-            if (event == ssdp.SSDP_ALIVE):
-                self.__handle_ssdp_alive(uuid, location, max_age)
-
-            elif (event == ssdp.SSDP_BYEBYE):
-                self.__handle_ssdp_byebye(uuid)
-
-        #end if
+        callback = req.get_header("CALLBACK")
+        nt = req.get_header("NT")
+        sid = req.get_header("SID")
+        timeout = req.get_header("TIMEOUT") or "Second-1800"
         
-        return True
-
+    
 
     def __handle_ssdp_alive(self, uuid, location, max_age):
     
-        logging.debug("UPnP device %s is ALIVE, max-age %ds", uuid, max_age)
+        logging.debug("[ssdp monitor] ALIVE from: %s, max-age %ds", uuid, max_age)
         if (not uuid in self.__servers and
                 not uuid in self.__processing):
             self.__servers[uuid] = location
@@ -125,18 +150,17 @@ class SSDPMonitor(Component):
                         
         # set up expiration handler
         if (uuid in self.__expiration_handlers):
-            logging.debug("UPnP device [%s] is still ALIVE", uuid)
-            print "got ALIVE from", uuid
+            logging.debug("[ssdp monitor] still ALIVE from: %s", uuid)
             gobject.source_remove(self.__expiration_handlers[uuid])
             
-        print uuid, "will expire in", max_age, "seconds"
+        logging.debug("[ssdp monitor] expires in %d seconds: %s", max_age, uuid)
         self.__expiration_handlers[uuid] = gobject.timeout_add(
                     max_age * 1000, self.__on_expire, uuid)
 
 
     def __handle_ssdp_byebye(self, uuid):
     
-        logging.debug("UPnP device %s is GONE", uuid)
+        logging.debug("[ssdp monitor] BYE-BYE from: %s", uuid)
         if (uuid in self.__servers):
             del self.__servers[uuid]
             if (uuid in self.__processing):
@@ -146,19 +170,42 @@ class SSDPMonitor(Component):
 
     def handle_COM_EV_APP_STARTED(self):
     
-        self.handle_SSDP_ACT_SEARCH_DEVICES()
+        error = self.emit_message(msgs.HTTPSERVER_SVC_BIND_UDP,
+                                  self, ssdp.SSDP_IP, ssdp.SSDP_PORT)
+        self.__start_discovery()
         
+        
+        
+    def handle_HTTPSERVER_EV_REQUEST(self, owner, req):
+    
+        if (owner != self): return
+        
+        method = req.get_method()
+        if (method == "M-SEARCH"):
+            self.emit_message(msgs.SSDP_EV_MSEARCH, req)
+                        
+        elif (method == "NOTIFY"):        
+            if (req.get_header("X-MEDIABOX-IGNORE") == network.get_ip()):
+                return
+                
+            max_age = ssdp.parse_max_age(req.get_header("CACHE-CONTROL"))
+            location = req.get_header("LOCATION")
+            usn = req.get_header("USN")
+            nts = req.get_header("NTS")
+            if ("::" in usn):
+                uuid, urn = usn.split("::")
+            else:
+                uuid = usn
+                urn = ""
+
+            if (nts == "ssdp:alive"):
+                self.__handle_ssdp_alive(uuid, location, max_age)
+
+            elif (nts == "ssdp:byebye"):
+                self.__handle_ssdp_byebye(uuid)
+
 
     def handle_SSDP_ACT_SEARCH_DEVICES(self):
     
-        # initialize monitor if needed
-        if (not self.__monitoring):
-            logging.info("SSDP Monitor waking up")
-            nsock, dsock = ssdp.open_sockets()
-            gobject.timeout_add(0, self.__discovery_chain, dsock, 0)
-            gobject.io_add_watch(nsock, gobject.IO_IN, self.__check_ssdp)
-            self.__discovery_monitor = gobject.io_add_watch(dsock, gobject.IO_IN, self.__check_ssdp)            
-            self.__monitoring = True
-        
-        else:
-            ssdp.discover_devices()
+        self.__start_discovery()
+
