@@ -1,8 +1,13 @@
 from utils.Config import Config
 
+RESUME_AUTOMATIC = "automatic"
+RESUME_MANUAL = "manual"
+
+
 _cfg = Config("system", [
               ("keep-display-lit", Config.STRING, "no"),
               ("max-battery", Config.INTEGER, 15000),
+              ("phonecall-resume", Config.STRING, RESUME_AUTOMATIC)
               ])
 
 
@@ -26,3 +31,13 @@ def get_max_battery():
 
     return _cfg["max-battery"]
 
+
+def set_phonecall_resume(v):
+
+    _cfg["phonecall-resume"] = v
+    
+
+def get_phonecall_resume():
+
+    return _cfg["phonecall-resume"]
+
