@@ -15,13 +15,13 @@ import time
 
 if (platforms.MAEMO4 or platforms.MAEMO5):
     # limit the IO rate
-    _BUFFER_SIZE = 1024
+    _BUFFER_SIZE = 65536
     _MAX_CONNECTIONS = 4
 else:
     _BUFFER_SIZE = 65536
     _MAX_CONNECTIONS = 12
 
-_CONNECTION_TIMEOUT = 10
+_CONNECTION_TIMEOUT = 30
 
 _connection_resource = threading.Semaphore(_MAX_CONNECTIONS)
 
@@ -107,8 +107,6 @@ class HTTPConnection(object):
     def __connect(self, host, port):
         """
         Opens an asynchronous connection to the given host and port.
-        Returns an event object that will signalize when the connection action
-        terminated. Once this event is set, the connection status may be read.
         """
 
         logging.debug("[conn %s] new HTTP connection: %s",
@@ -239,8 +237,7 @@ class HTTPConnection(object):
         before = time.time()
         while (not response.finished() and self.__sock and
                not self.__redirect_handled):
-            rfds, wfds, xfds = select.select([self.__sock], [], [],
-                                             _CONNECTION_TIMEOUT)
+            rfds, wfds, xfds = select.select([self.__sock], [], [])
             if (rfds):
                 chunk = rfds[0].recv(_BUFFER_SIZE)
                 if (len(chunk) == 0):
@@ -259,14 +256,12 @@ class HTTPConnection(object):
                         logging.debug("[conn %s] %0.2f kB/s",
                                       self._get_id(), size_diff / 1024.0)
                     #end if
-                    
-                    
-                    
 
             else:
                 # timeout
                 self.__emit(self.__abort, "TIMEOUT")
                 return
+            time.sleep(0.1)
         #end while
         
         
