@@ -179,9 +179,6 @@ class AbstractBackend(EventEmitter):
             (self.__STATE_IDLE,            None,
              no_error,                     self.__STATE_UNLOADED),
 
-            #(self.__STATE_EOF,             _INPUT_LOAD,
-            # no_error,                     self.__STATE_LOADED),
-
             (self.__STATE_EOF,             None,
              no_error,                     self.__STATE_UNLOADED),
 
@@ -221,21 +218,25 @@ class AbstractBackend(EventEmitter):
         
     def __on_enter_unloaded(self, sm):
     
+        logging.debug("[mediaplayer] entering state UNLOADED")
         # make sure the backend is unloaded
         self._close()
         
         
     def __on_leave_unloaded(self, sm):
     
+        logging.debug("[mediaplayer] leaving state UNLOADED")
         # load backend
         self._ensure_backend()
         
         
     def __on_enter_loaded(self, sm):
     
+        logging.debug("[mediaplayer] entering state LOADED")
+        
         # clear tags
         sm.get_property("tags").clear()
-                
+
         # resume from suspension point
         susp = sm.get_property("suspension point")
         if (susp):
@@ -245,10 +246,15 @@ class AbstractBackend(EventEmitter):
 
         # load file
         self._load(uri)
+
+        load_time = sm.get_property("load time")
+        logging.profile(load_time, "[mediaplayer] loaded media")
         
         
     def __on_enter_playing(self, sm):
     
+        logging.debug("[mediaplayer] entering state PLAYING")
+    
         # resume from suspension point and invalidate it
         susp = sm.get_property("suspension point")
         if (susp):
@@ -263,8 +269,11 @@ class AbstractBackend(EventEmitter):
     
         # start playloop
         if (not self.__position_handler):
+            t = time.time()
+            logging.debug("[mediaplayer] starting position handler at %d",
+                          int(t))
             self.__position_handler = \
-                  gobject.timeout_add(0, self.__update_position, 0, time.time())
+                  gobject.timeout_add(0, self.__update_position, 0, t)
 
         # notify
         gobject.timeout_add(0, self.emit_event, self.EVENT_STATUS_CHANGED,
@@ -274,14 +283,19 @@ class AbstractBackend(EventEmitter):
         
     def __on_leave_playing(self, sm):
     
+        logging.debug("[mediaplayer] leaving state PLAYING")
+    
         # stop playloop
         if (self.__position_handler):
             gobject.source_remove(self.__position_handler)
+            logging.debug("[mediaplayer] stopping position handler")
         self.__position_handler = None
 
 
     def __on_enter_eof(self, sm):
 
+        logging.debug("[mediaplayer] entering state EOF")
+
         # start idle timeout
         if (self.__idle_handler):
             gobject.source_remove(self.__idle_handler)
@@ -289,13 +303,15 @@ class AbstractBackend(EventEmitter):
                                                   self.__on_idle_timeout)
     
         # notify
-        logging.info("reached end-of-file")
+        logging.info("[mediaplayer] reached end-of-file")
         self.emit_event(self.EVENT_STATUS_CHANGED,
                         sm.get_property("context id"), self.STATUS_EOF)
 
 
     def __on_leave_eof(self, sm):
     
+        logging.debug("[mediaplayer] leaving state EOF")
+    
         # stop idle timeout
         if (self.__idle_handler):
             gobject.source_remove(self.__idle_handler)
@@ -303,6 +319,8 @@ class AbstractBackend(EventEmitter):
 
     def __on_enter_paused(self, sm):
     
+        logging.debug("[mediaplayer] entering state PAUSED")
+    
         self._stop()
     
         # start idle timeout
@@ -318,6 +336,8 @@ class AbstractBackend(EventEmitter):
 
     def __on_leave_paused(self, sm):
     
+        logging.debug("[mediaplayer] leaving state PAUSED")
+    
         # stop idle timeout
         if (self.__idle_handler):
             gobject.source_remove(self.__idle_handler)
@@ -325,6 +345,8 @@ class AbstractBackend(EventEmitter):
         
     def __on_enter_idle(self, sm):
     
+        logging.debug("[mediaplayer] entering state IDLE")
+    
         # set suspension point
         pos = sm.get_property("position")
         total = sm.get_property("length")
@@ -334,6 +356,8 @@ class AbstractBackend(EventEmitter):
    
     def __on_enter_error(self, sm):
     
+        logging.debug("[mediaplayer] entering state ERROR")
+    
         ctx_id = sm.get_property("context id")
         err = sm.get_property("error")
         sm.set_property("error", self.NO_ERROR)
@@ -439,7 +463,7 @@ class AbstractBackend(EventEmitter):
         Reacts on idle timeout and suspends the player.
         """
 
-        logging.info("media backend idle timeout")
+        logging.info("[mediaplayer] media backend idle timeout")
         self.__state_machine.send_input(_INPUT_IDLE)
             
 
@@ -488,7 +512,9 @@ class AbstractBackend(EventEmitter):
     
         uris = []
         try:
+            stopwatch = logging.stopwatch()
             fd = urllib.urlopen(url)
+            logging.profile(stopwatch, "[mediaplayer] retrieved playlist")
         except:
             return uris
             
@@ -550,7 +576,9 @@ class AbstractBackend(EventEmitter):
         """
 
         if (uri.startswith("http") and not uri.startswith("http://127.0.0.1")):
+            stopwatch = logging.stopwatch()
             s_type = self.__stream_analyzer.analyze(uri)
+            logging.profile(stopwatch, "[mediaplayer] analyzed stream type")
         else:
             s_type = StreamAnalyzer.STREAM
 
@@ -561,13 +589,13 @@ class AbstractBackend(EventEmitter):
             else:
                 uri = ""
 
-        print "LOAD", uri
         # new context id is needed
         self.__state_machine.set_property("context id", self._new_context_id())
 
         self.__state_machine.set_property("suspension point", None)
         self.__state_machine.set_property("uri", uri)
-        self.__state_machine.send_input(_INPUT_LOAD)
+        self.__state_machine.set_property("load time", time.time())
+        gobject.idle_add(self.__state_machine.send_input, _INPUT_LOAD)
 
         return self.__state_machine.get_property("context id")
 
