@@ -296,7 +296,7 @@ class ProgressBar(Widget):
 
     def set_position(self, pos, total):
 
-        self.set_message("")
+        #self.set_message("")
         if (self.__is_dragging and self.__dragged_bookmark == -1): return
         if (not self.may_render()): return
         if (total == 0): return
@@ -316,7 +316,7 @@ class ProgressBar(Widget):
         @param amount: the amount value
         """
 
-        self.set_message("")
+        #self.set_message("")
         if (self.__is_dragging and self.__dragged_bookmark == -1): return
         if (not self.may_render()): return
         
