@@ -472,6 +472,10 @@ class Window(Widget):
                 else:
                     self.__window.unfullscreen()
 
+            elif (platforms.MAEMO4):
+                self.__title_bar.set_visible(not value)
+                self.render()
+
             else:
                 if (self.__title_bar):
                     self.__title_bar.set_visible(not value)
@@ -725,8 +729,9 @@ class Window(Widget):
 
 
     def hide_video_overlay(self):
-    
-        self.__vidscreen.hide()
+
+        #self.__vidscreen.hide()
+        gobject.idle_add(self.__vidscreen.hide)
 
 
     def run(self):
