@@ -1,9 +1,14 @@
 import ctypes
 import os
 
+NORMAL = 1
+LEFT = 2
+INVERTED = 4
+RIGHT = 8
+
 _xlib = ctypes.CDLL("libX11.so.6")
 _xrandr = ctypes.CDLL("libXrandr.so.2")
-rr = _xrandr
+_rr = _xrandr
 
 class _XRRScreenConfiguration(ctypes.Structure): pass
 
@@ -14,22 +19,22 @@ def set_orientation(orientation):
     screen = _xlib.XDefaultScreen(display)
     root = _xlib.XDefaultRootWindow(display, screen)
 
-    gsi = rr.XRRGetScreenInfo
+    gsi = _rr.XRRGetScreenInfo
     gsi.restype = ctypes.POINTER(_XRRScreenConfiguration)
     config = gsi(display, root)
 
     current_time = ctypes.c_ulong()
-    rr.XRRTimes.restype = ctypes.c_ulong
-    timestamp = rr.XRRTimes(display, screen, ctypes.byref(current_time))
+    _rr.XRRTimes.restype = ctypes.c_ulong
+    timestamp = _rr.XRRTimes(display, screen, ctypes.byref(current_time))
 
-    xccr = rr.XRRConfigCurrentRate
+    xccr = _rr.XRRConfigCurrentRate
     xccr.restype = ctypes.c_int
     rate = xccr(config)
 
     rotation = ctypes.c_ushort()
-    size = rr.XRRConfigCurrentConfiguration(config, ctypes.byref(rotation))
+    size = _rr.XRRConfigCurrentConfiguration(config, ctypes.byref(rotation))
 
 
-    rr.XRRSetScreenConfigAndRate(display, config, root, size,
-                                 int(orientation), rate, timestamp)
+    _rr.XRRSetScreenConfigAndRate(display, config, root, size,
+                                  orientation, rate, timestamp)
 
